@@ -1,6 +1,6 @@
 package BibTeX::Parser;
 {
-  $BibTeX::Parser::VERSION = '0.64';
+  $BibTeX::Parser::VERSION = '0.65';
 }
 # ABSTRACT: A pure perl BibTeX parser
 use warnings;
@@ -210,6 +210,7 @@ sub _extract_bracketed
 
 1;    # End of BibTeX::Parser
 
+
 __END__
 =pod
 
@@ -219,7 +220,7 @@ BibTeX::Parser - A pure perl BibTeX parser
 
 =head1 VERSION
 
-version 0.64
+version 0.65
 
 =head1 SYNOPSIS
 
@@ -262,7 +263,7 @@ BibTeX::Parser - A pure perl BibTeX parser
 
 =head1 VERSION
 
-version 0.64
+version 0.65
 
 =head1 FUNCTIONS
 
@@ -278,13 +279,27 @@ Parameters:
 
 Returns the next parsed entry or undef.
 
+=head2 SEE ALSO
+
+=over 4
+
+=item
+
+L<BibTeX::Parser::Entry>
+
+=item
+
+L<BibTeX::Parser::Author>
+
+=back
+
 =head1 AUTHOR
 
 Gerhard Gossen <gerhard.gossen@googlemail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Gerhard Gossen.
+This software is copyright (c) 2013 by Gerhard Gossen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
